Snippet A: Print a greeting

```python
import numpy as np
print('Hello from MDRUN.py demo!')
a=3+2
```
```
Hello from MDRUN.py demo!

```

Snippet B: Define a function

```python
def f(x):
  return x*x
```
```
... ... 
```

Snippet C: Evaluate the function defined above

```python
print(f(a))
```
```
25

```

The end.




